import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConfigServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConfigServiceClient";
import { DeleteRetentionConfigurationRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteRetentionConfigurationCommand}.
 */
export interface DeleteRetentionConfigurationCommandInput extends DeleteRetentionConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteRetentionConfigurationCommand}.
 */
export interface DeleteRetentionConfigurationCommandOutput extends __MetadataBearer {
}
declare const DeleteRetentionConfigurationCommand_base: {
    new (input: DeleteRetentionConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteRetentionConfigurationCommandInput, DeleteRetentionConfigurationCommandOutput, ConfigServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteRetentionConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteRetentionConfigurationCommandInput, DeleteRetentionConfigurationCommandOutput, ConfigServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes the retention configuration.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConfigServiceClient, DeleteRetentionConfigurationCommand } from "@aws-sdk/client-config-service"; // ES Modules import
 * // const { ConfigServiceClient, DeleteRetentionConfigurationCommand } = require("@aws-sdk/client-config-service"); // CommonJS import
 * const client = new ConfigServiceClient(config);
 * const input = { // DeleteRetentionConfigurationRequest
 *   RetentionConfigurationName: "STRING_VALUE", // required
 * };
 * const command = new DeleteRetentionConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteRetentionConfigurationCommandInput - {@link DeleteRetentionConfigurationCommandInput}
 * @returns {@link DeleteRetentionConfigurationCommandOutput}
 * @see {@link DeleteRetentionConfigurationCommandInput} for command's `input` shape.
 * @see {@link DeleteRetentionConfigurationCommandOutput} for command's `response` shape.
 * @see {@link ConfigServiceClientResolvedConfig | config} for ConfigServiceClient's `config` shape.
 *
 * @throws {@link InvalidParameterValueException} (client fault)
 *  <p>One or more of the specified parameters are not valid. Verify
 * 			that your parameters are valid and try again.</p>
 *
 * @throws {@link NoSuchRetentionConfigurationException} (client fault)
 *  <p>You have specified a retention configuration that does not exist.</p>
 *
 * @throws {@link ConfigServiceServiceException}
 * <p>Base exception class for all service exceptions from ConfigService service.</p>
 *
 *
 * @public
 */
export declare class DeleteRetentionConfigurationCommand extends DeleteRetentionConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteRetentionConfigurationRequest;
            output: {};
        };
        sdk: {
            input: DeleteRetentionConfigurationCommandInput;
            output: DeleteRetentionConfigurationCommandOutput;
        };
    };
}
